==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property includedPaths
 */
public data class RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs(
    public val all:
    Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgs>? =
        null,
    public val includedPaths: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs> {
    override fun toJava():
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .includedPaths(includedPaths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgs>? =
        null

    private var includedPaths: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("xccgwevkvhqkxhiv")
    public suspend
    fun all(`value`: Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("pdgfhmnnijbcvomy")
    public suspend fun includedPaths(`value`: Output<List<String>>) {
        this.includedPaths = value
    }

    @JvmName("xnmvmmwmpoldgfls")
    public suspend fun includedPaths(vararg values: Output<String>) {
        this.includedPaths = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("typhiesjatipflhs")
    public suspend fun includedPaths(values: List<Output<String>>) {
        this.includedPaths = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("klmarhsbceotngbo")
    public suspend
    fun all(`value`: RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("opnoconncoqiojxp")
    public suspend
    fun all(argument: suspend RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("fhgauevejfrbkwyr")
    public suspend fun includedPaths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedPaths = mapped
    }

    /**
     * @param values
     */
    @JvmName("kirxvelknvsqmucy")
    public suspend fun includedPaths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedPaths = mapped
    }

    internal fun build():
        RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs =
        RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs(
            all = all,
            includedPaths = includedPaths,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/wafv2/kotlin/inputs/RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.wafv2.kotlin.inputs

import com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property all An empty configuration block that is used for inspecting all headers.
 * @property includedPaths
 */
public data class RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs(
    public val all: Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgs>? =
        null,
    public val includedPaths: Output<List<String>>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs> {
    override fun toJava(): com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs =
        com.pulumi.aws.wafv2.inputs.RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs.builder()
            .all(all?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .includedPaths(includedPaths?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs].
 */
@PulumiTagMarker
public class RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgsBuilder
internal constructor() {
    private var all:
        Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgs>? =
        null

    private var includedPaths: Output<List<String>>? = null

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("ijsbxobbrmtgoedt")
    public suspend fun all(`value`: Output<RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgs>) {
        this.all = value
    }

    /**
     * @param value
     */
    @JvmName("gjtifiuyregtqlto")
    public suspend fun includedPaths(`value`: Output<List<String>>) {
        this.includedPaths = value
    }

    @JvmName("bfimidawqjxdsbpp")
    public suspend fun includedPaths(vararg values: Output<String>) {
        this.includedPaths = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("uolpfqperbjyvgfn")
    public suspend fun includedPaths(values: List<Output<String>>) {
        this.includedPaths = Output.all(values)
    }

    /**
     * @param value An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("uaermqxolcsrvotv")
    public suspend fun all(`value`: RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.all = mapped
    }

    /**
     * @param argument An empty configuration block that is used for inspecting all headers.
     */
    @JvmName("ofmlfxagfsagthac")
    public suspend fun all(argument: suspend RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgsBuilder.() -> Unit) {
        val toBeMapped =
            RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternAllArgsBuilder().applySuspend {
                argument()
            }.build()
        val mapped = of(toBeMapped)
        this.all = mapped
    }

    /**
     * @param value
     */
    @JvmName("mdgatsfltjiyefkx")
    public suspend fun includedPaths(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.includedPaths = mapped
    }

    /**
     * @param values
     */
    @JvmName("clduaehvlswbbkwt")
    public suspend fun includedPaths(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.includedPaths = mapped
    }

    internal fun build(): RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs =
        RuleGroupRuleStatementRegexMatchStatementFieldToMatchJsonBodyMatchPatternArgs(
            all = all,
            includedPaths = includedPaths,
        )
}
